@@ -7,6 +7,7 @@
 """
 Contains handlers for the Mito API
 """
+from mitosheet.api.get_excel_file_metadata import get_excel_file_metadata
 from mitosheet.api.get_pivot_params import get_pivot_params
 from queue import Queue
 from threading import Thread
@@ -121,6 +122,8 @@ def handle_api_event(send, event, steps_manager):
         result = get_saved_analysis_description(event, steps_manager)
     elif event['type'] == 'get_pivot_params':
         result = get_pivot_params(event, steps_manager)
+    elif event['type'] == 'get_excel_file_metadata':
+        result = get_excel_file_metadata(event, steps_manager)
     elif event['type'] == 'get_unique_value_counts':
         result = get_unique_value_counts(event, steps_manager)
     else:
