@@ -14,7 +14,7 @@ def get_filenames_with_suffix(*suffixes):
     return [str(filename) for filename in filenames if filename.suffix in suffixes]
 
 
-def get_datafiles(send, event):
+def get_datafiles(event):
     """
     Handles a `datafiles` api call, and returns all the csv files
     in the current folder.
@@ -25,8 +25,4 @@ def get_datafiles(send, event):
         '.tab',
     )
     # TODO: also get the XLSX files, when we can import them
-    send({
-        'event': 'api_response',
-        'id': event['id'],
-        'data': csv_files
-    })
\ No newline at end of file
+    return csv_files
\ No newline at end of file
