@@ -236,7 +236,7 @@ def make_unsupported_function_error(functions: Set[str], error_modal=True):
         error_modal=error_modal
     )
 
-def make_invalid_column_delete_error(column_header, dependents):
+def make_invalid_column_delete_error(column_headers, dependents):
     """
     Helper function for creating a invalid_column_delete_error.
 
@@ -246,18 +246,10 @@ def make_invalid_column_delete_error(column_header, dependents):
     # We make sure it's a list, for easy accessing!
     dependents = list(dependents)
 
-    # We make the error message read nicely!
-    if len(dependents) == 1:
-        dependent_string = f'column {dependents[0]}'
-    elif len(dependents) == 2:
-        dependent_string = f'columns {dependents[0]} and {dependents[1]}'
-    else:
-        dependent_string = f'columns {", ".join(dependents[: -1])}, and {dependents[-1]}'
-
     return MitoError(
         'invalid_column_delete_error',
         'Column Has Dependents',
-        f'{column_header} cannot be deleted, as it is referenced in {dependent_string}. Please remove these references before deleting.'
+        f'{(", ").join(column_headers)} cannot be deleted, as {"they are" if len(column_headers) > 1 else "it is"} referenced in {(", ".join(dependents))}. Please remove these references before deleting.'
     )
 
 def make_invalid_arguments_error(function):
