@@ -1,15 +1,16 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
+# Copyright (c) Mito.
+# Distributed under the terms of the Modified BSD License.
+
 from typing import Any, Dict, List
 
 from mitosheet.saved_analyses.step_upgraders.utils_column_header_to_column_id import \
     replace_headers_with_id
 
 
-def upgrade_change_column_dtype_1_to_2(step: Dict[str, Any], later_steps: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
+def upgrade_change_column_dtype_1_to_2(step: Dict[str, Any], later_steps: List[Dict[str, Any]]):
     """
     Moves to using column id instead of column header.
 
