@@ -20,7 +20,7 @@ import numpy as np
 
 from mitosheet.sheet_functions.types import NUMBER_SERIES
 from mitosheet.sheet_functions.types.decorators import filter_nans, convert_args_to_series_type, convert_arg_to_series_type, handle_sheet_function_errors
-from mitosheet.sheet_functions.sheet_function_utils import fill_series_list_to_max, fill_series_to_length
+from mitosheet.sheet_functions.sheet_function_utils import try_extend_series_to_index, fill_series_with_one_index, fill_series_with_one_index
 
 @handle_sheet_function_errors
 @convert_arg_to_series_type(
@@ -75,7 +75,7 @@ def AVG(*argv) -> pd.Series:
     }
     """
     # Fill sum to the max length of any series
-    argv = fill_series_list_to_max(argv)
+    argv = fill_series_with_one_index(argv)
 
     arg_sum = functools.reduce((lambda x, y: x + y), argv) 
     return arg_sum / len(argv)
@@ -116,7 +116,8 @@ def CORR(s1, s2) -> pd.Series:
     """
     corr = s1.corr(s2, method='pearson')
     return pd.Series(
-        [corr] * len(s1)
+        [corr] * len(s1),
+        index=s1.index
     )
 
 
@@ -147,7 +148,8 @@ def KURT(series) -> pd.Series:
     """
     kurtosis = series.kurtosis()
     return pd.Series(
-        [kurtosis] * len(series)
+        [kurtosis] * len(series),
+        index=series.index
     )
 
 
@@ -177,6 +179,7 @@ def MAX(*argv) -> pd.Series:
     }
     """
     # We make a dataframe out of the series, and take the max between all the columns
+    argv = fill_series_with_one_index(argv)
     return pd.DataFrame(argv).max()
 
 
@@ -206,6 +209,7 @@ def MIN(*argv) -> pd.Series:
     }
     """
     # We make a dataframe out of the series, and take the min between all the columns
+    argv = fill_series_with_one_index(argv)
     return pd.DataFrame(argv).min()
 
 
@@ -234,7 +238,7 @@ def MULTIPLY(*argv) -> pd.Series:
     }
     """
     # We make sure all the series are the max length, so the * has something at every index
-    argv = fill_series_list_to_max(argv)
+    argv = fill_series_with_one_index(argv)
 
     return functools.reduce((lambda x, y: x * y), argv) 
 
@@ -274,7 +278,7 @@ def POWER(series, power):
         ]
     }
     """
-    power = fill_series_to_length(power, len(series))
+    power = try_extend_series_to_index(power, series.index)
     return series.pow(power)
 
 
@@ -320,10 +324,11 @@ def ROUND(series, decimals=None):
         return series.round()
     
     # Otherwise, fill the decimals to length
-    decimals = fill_series_to_length(decimals, series.size)
+    decimals = try_extend_series_to_index(decimals, series.index)
 
     return pd.Series(
-        [round(num, dec) for num, dec in zip(series, decimals)]
+        [round(num, dec) for num, dec in zip(series, decimals)],
+        index=series.index
     )
 
 @handle_sheet_function_errors
@@ -353,7 +358,8 @@ def SKEW(series) -> pd.Series:
     """
     skew = series.skew()
     return pd.Series(
-        [skew] * len(series)
+        [skew] * len(series),
+        index=series.index
     )
 
 
@@ -383,7 +389,7 @@ def SUM(*argv) -> pd.Series:
     }
     """
     # Fill sum to the max length of any series
-    argv = fill_series_list_to_max(argv)
+    argv = fill_series_with_one_index(argv)
 
     return functools.reduce((lambda x, y: x + y), argv) 
 
@@ -415,7 +421,8 @@ def STDEV(series) -> pd.Series:
     """
     std = series.std()
     return pd.Series(
-        [std] * len(series)
+        [std] * len(series),
+        index=series.index
     )
 
 
@@ -503,7 +510,8 @@ def VAR(series) -> pd.Series:
     """
     var = series.var()
     return pd.Series(
-        [var] * len(series)
+        [var] * len(series),
+        index=series.index
     )
 
 # TODO: we should see if we can list these automatically!
