@@ -11,7 +11,7 @@ from typing import Tuple, Union
 import pandas as pd
 import numpy as np
 
-from mitosheet.sheet_functions.types.utils import BOOLEAN_SERIES, DATETIME_SERIES, NUMBER_SERIES, STRING_SERIES, get_mito_type
+from mitosheet.sheet_functions.types.utils import BOOLEAN_SERIES, DATETIME_SERIES, NUMBER_SERIES, STRING_SERIES, get_billion_identifier_in_string, get_million_identifier_in_string, get_mito_type
 
 
 def convert_string_to_number(
@@ -28,6 +28,7 @@ def convert_string_to_number(
         where commas may represent a decimal. However, this is impossible to make perfect, as 123,123 and
         123,123 are 123123 and 123.123 in America and Europe respectively. We treat this as American for 
         now. 
+    5. Million or Billion identifier in the string
     As these are all heuristics, we do our best. We also try to perform this conversion
     optimistically, as to run as quickly as possible.
     """
@@ -52,7 +53,7 @@ def convert_string_to_number(
             s = s[1:-1]
             is_negative = True
 
-        # Finially, handle case 4, if it's an issue
+        # Handle case 4, if it's an issue
         if ',' in s:
             # We try and figure out if it's a european or american comma usage, by seeing
             # what happens at the end of the string
@@ -65,9 +66,22 @@ def convert_string_to_number(
             else:
                 # Otherwise, we treat this as American
                 s = s.replace(',', '')
-    
+
+        # Handle case 5, if there is a million or billion identifier in the number
+        million_identifer = get_million_identifier_in_string(s)
+        billion_identifier = get_billion_identifier_in_string(s)
+        multiplier = 1
+
+        if million_identifer != None:
+            multiplier = 1000000
+            s = s.replace(million_identifer, '')
+
+        if billion_identifier != None:
+            multiplier = 1000000000
+            s = s.replace(billion_identifier, '')
+
         try:
-            return float(s) * (-1 if is_negative else 1)
+            return float(s) * (-1 if is_negative else 1) * multiplier
         except:
             if on_uncastable_arg_element == 'error':
                 # TODO: raise a better exception
