@@ -10,6 +10,7 @@ how to add a step!
 """
 
 from typing import Dict, List
+from mitosheet.step_performers.import_steps.excel_import import ExcelImportStepPerformer
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.step_performers.pivot import PivotStepPerformer
 from mitosheet.step_performers.filter import FilterStepPerformer
@@ -42,6 +43,7 @@ STEP_PERFORMERS: List[StepPerformer] = [
     DeleteColumnStepPerformer,
     RenameColumnStepPerformer,
     SimpleImportStepPerformer,
+    ExcelImportStepPerformer,
     DataframeDeleteStepPerformer,
     DataframeDuplicateStepPerformer,
     DataframeRenameStepPerformer,
@@ -58,4 +60,4 @@ EVENT_TYPE_TO_STEP_PERFORMER: Dict[str, StepPerformer] = {
 STEP_TYPE_TO_STEP_PERFORMER: Dict[str, StepPerformer] = {
     step_performer.step_type(): step_performer
     for step_performer in STEP_PERFORMERS
-}
\ No newline at end of file
+}
