@@ -88,7 +88,13 @@ class RenameColumnStepPerformer(StepPerformer):
 
         df_name = post_state.df_names[sheet_index]
         old_column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
-        rename_dict = "{\"" + old_column_header + "\": \"" + new_column_header + "\"}"
+
+        # TODO: in the future, make sure we handle transpiling other column headers better
+        if isinstance(old_column_header, int) or isinstance(old_column_header, float) or isinstance(old_column_header, bool):
+            rename_dict = "{" + str(old_column_header) + ": \"" + new_column_header + "\"}"
+        else:
+            rename_dict = "{\"" + old_column_header + "\": \"" + new_column_header + "\"}"
+        
         return [f'{df_name}.rename(columns={rename_dict}, inplace=True)']
 
     @classmethod
