@@ -16,7 +16,7 @@ from mitosheet.sheet_functions import FUNCTIONS
 from mitosheet.parser import parse_formula
 
 from mitosheet.errors import (
-    EditError,
+    MitoError,
     make_circular_reference_error,
     make_execution_error, 
     make_no_column_error, 
@@ -84,7 +84,7 @@ class SetColumnFormulaStepPerformer(StepPerformer):
 
         # First, we check the column_metatype, and make sure it's a formula
         if prev_state.column_metatype[sheet_index][column_id] != 'formula':
-            raise make_wrong_column_metatype_error(column_header)
+            raise make_wrong_column_metatype_error(column_header, error_modal=False)
 
         # If nothings changed, there's no work to do
         if (old_formula == new_formula):
@@ -103,12 +103,12 @@ class SetColumnFormulaStepPerformer(StepPerformer):
         # We check that the formula doesn't reference any columns that don't exist
         missing_columns = new_dependencies.difference(prev_state.column_metatype[sheet_index].keys())
         if any(missing_columns):
-            raise make_no_column_error(missing_columns)
+            raise make_no_column_error(missing_columns, error_modal=False)
 
         # The formula can only reference known formulas
         missing_functions = new_functions.difference(set(FUNCTIONS.keys()))
         if any(missing_functions):
-            raise make_unsupported_function_error(missing_functions)
+            raise make_unsupported_function_error(missing_functions, error_modal=False)
 
         # Then, we get the list of old column dependencies and new dependencies
         # so that we can update the graph
@@ -124,14 +124,22 @@ class SetColumnFormulaStepPerformer(StepPerformer):
             new_dependencies
         )
         if circularity:
-            raise make_circular_reference_error()
+            raise make_circular_reference_error(error_modal=False)
 
         # We check out a new step
         post_state = deepcopy(prev_state)
 
         # Update the column formula, and then execute the new formula graph
-        _update_column_formula_in_step(post_state, sheet_index, column_id, old_formula, new_formula)
-        refresh_dependant_columns(post_state, post_state.dfs[sheet_index], sheet_index)
+        try:
+            _update_column_formula_in_step(post_state, sheet_index, column_id, old_formula, new_formula)
+            refresh_dependant_columns(post_state, post_state.dfs[sheet_index], sheet_index)
+        except MitoError as e:
+            # Catch the error and make sure that we don't set the error modal
+            e.error_modal = False
+            raise e
+        except:
+            raise make_execution_error(error_modal=False)
+
 
         # Finially, update the type of the filters of this column, for all the filters
         # TODO: fix bug where we have to update downstream types, but note that
