@@ -11,6 +11,7 @@ from mitosheet.errors import make_incompatible_merge_key_error
 from mitosheet.sheet_functions.types.utils import get_mito_type
 from mitosheet.state import DATAFRAME_SOURCE_MERGED, State
 from mitosheet.step_performers.step_performer import StepPerformer
+from mitosheet.transpiler.transpile_utils import column_header_to_transpiled_code
 
 
 class MergeStepPerformer(StepPerformer):
@@ -110,7 +111,7 @@ class MergeStepPerformer(StepPerformer):
         if how == 'lookup':
             # If the mege is a lookup, then we add the drop duplicates code
             temp_df_name = 'temp_df'
-            merge_code.append(f'{temp_df_name} = {df_two_name}.drop_duplicates(subset=\'{merge_key_two}\') # Remove duplicates so lookup merge only returns first match')
+            merge_code.append(f'{temp_df_name} = {df_two_name}.drop_duplicates(subset={column_header_to_transpiled_code(merge_key_two)}) # Remove duplicates so lookup merge only returns first match')
             how_to_use = 'left'
         else:
             temp_df_name = df_two_name
@@ -140,7 +141,7 @@ class MergeStepPerformer(StepPerformer):
 
         # Finially append the merge
         merge_code.append(
-            f'{df_new_name} = {df_one_to_merge}.merge({df_two_to_merge}, left_on=[\'{merge_key_one}\'], right_on=[\'{merge_key_two}\'], how=\'{how_to_use}\', suffixes=[\'_{suffix_one}\', \'_{suffix_two}\'])'
+            f'{df_new_name} = {df_one_to_merge}.merge({df_two_to_merge}, left_on=[{column_header_to_transpiled_code(merge_key_one)}], right_on=[{column_header_to_transpiled_code(merge_key_two)}], how=\'{how_to_use}\', suffixes=[\'_{suffix_one}\', \'_{suffix_two}\'])'
         )
 
         # And then return it
