@@ -8,7 +8,7 @@ from copy import deepcopy
 from typing import Any, Dict, List, Optional, Union
 
 import numpy as np
-from mitosheet.errors import make_no_column_error
+from mitosheet.errors import make_cast_value_to_type_error, make_no_column_error
 from mitosheet.sheet_functions.types import SERIES_CONVERSION_FUNCTIONS
 from mitosheet.sheet_functions.types.utils import (BOOLEAN_SERIES,
                                                    NUMBER_SERIES,
@@ -72,7 +72,7 @@ class SetCellValueStepPerformer(StepPerformer):
         **params
     ) -> State:
         if column_id not in prev_state.column_metatype[sheet_index]:
-            raise make_no_column_error([column_id])
+            raise make_no_column_error([column_id], error_modal=False)
 
         # If nothings changed, there's no work to do
         if old_value == new_value:
@@ -171,17 +171,20 @@ def cast_value_to_type(value: Union[str, None], mito_series_type: str):
     if is_none_type(value):
         return None
 
-    conversion_function = SERIES_CONVERSION_FUNCTIONS[mito_series_type]
-    casted_value_series = conversion_function(value, on_uncastable_arg_element=np.NaN)
+    try:
+        conversion_function = SERIES_CONVERSION_FUNCTIONS[mito_series_type]
+        casted_value_series = conversion_function(value, on_uncastable_arg_element=np.NaN)
 
-    type_corrected_new_value = casted_value_series.iat[0]
+        type_corrected_new_value = casted_value_series.iat[0]
 
-    # If the value is a string and it has a " in it, replace it with a ' so the transpiled code does not error
-    if mito_series_type == STRING_SERIES and '"' in type_corrected_new_value:
-        type_corrected_new_value = type_corrected_new_value.replace('"', "'")
+        # If the value is a string and it has a " in it, replace it with a ' so the transpiled code does not error
+        if mito_series_type == STRING_SERIES and '"' in type_corrected_new_value:
+            type_corrected_new_value = type_corrected_new_value.replace('"', "'")
 
-    # If the typed value is not a float, then we do not make it one
-    if mito_series_type == NUMBER_SERIES and '.' not in value:
-        return round(type_corrected_new_value)
+        # If the typed value is not a float, then we do not make it one
+        if mito_series_type == NUMBER_SERIES and '.' not in value:
+            return round(type_corrected_new_value)
 
-    return type_corrected_new_value
+        return type_corrected_new_value
+    except:
+        raise make_cast_value_to_type_error(value, mito_series_type.replace('_', ' '), error_modal=False)
