@@ -8,9 +8,9 @@ import uuid
 from copy import copy, deepcopy
 import pandas as pd
 from typing import List, Tuple
-from mitosheet.saved_analyses.save_utils import read_saved_analysis_names
 
 from mitosheet.step_performers.import_steps.simple_import import SimpleImportStepPerformer
+from mitosheet.step_performers.import_steps.excel_import import ExcelImportStepPerformer
 from mitosheet.state import State
 from mitosheet.step import Step
 from mitosheet.step_performers import EVENT_TYPE_TO_STEP_PERFORMER
@@ -18,11 +18,7 @@ from mitosheet.updates import UPDATES
 from mitosheet.preprocessing import PREPROCESS_STEP_PERFORMERS
 from mitosheet.utils import dfs_to_json, get_new_id
 from mitosheet.transpiler.transpile import transpile
-from mitosheet.user import get_user_field
 from mitosheet.data_in_mito import DataTypeInMito, get_data_type_in_mito
-from mitosheet.user import (
-    UJ_USER_EMAIL, UJ_RECEIVED_TOURS
-)
 
 
 def get_step_indexes_to_skip(step_list: List[Step]):
@@ -421,7 +417,8 @@ class StepsManager():
             step for step in self.steps
             if (
                 step.step_type == 'initialize' or \
-                step.step_type == SimpleImportStepPerformer.step_type()
+                step.step_type == SimpleImportStepPerformer.step_type() or \
+                step.step_type == ExcelImportStepPerformer.step_type()
             )
         ]
 
