@@ -1,15 +1,16 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
+# Copyright (c) Mito.
+# Distributed under the terms of the Modified BSD License.
+
 """
 Contains tests for errors during executing being rolled back properly
 """
 
 import pytest
 
-from mitosheet.tests.test_utils import create_mito_wrapper_with_data
+from mitosheet.tests.test_utils import create_mito_wrapper
 
 INVALID_FORMULAS = [
     ("=1()"),
@@ -27,7 +28,7 @@ def test_invalid_formulas_dont_change_df(invalid_formula):
     Makes sure that a column does not change when it is set to an
     invalid formula.
     """
-    mito = create_mito_wrapper_with_data([123])
+    mito = create_mito_wrapper([123])
     mito.add_column(0, 'B')
     # Set the invalid formula
     mito.set_formula(invalid_formula, 0, 'B')
