@@ -107,13 +107,13 @@ def test_preserves_order_columns():
         'df1.insert(2, \'C\', 0)',
     ]
 
-def test_transpile_delete_column():
+def test_transpile_delete_columns():
     df1 = pd.DataFrame(data={'A': [1], 'B': [101], 'C': [11]})
     mito = create_mito_wrapper_dfs(df1)
-    mito.delete_column(0, 'C')
+    mito.delete_columns(0, ['C', 'B'])
 
     assert mito.transpiled_code == [
-        'df1.drop(\'C\', axis=1, inplace=True)'
+        'df1.drop([\'C\', \'B\'], axis=1, inplace=True)'
     ]
 
 
@@ -168,7 +168,7 @@ def test_optimization_with_other_edits():
     mito.set_formula('=A', 0, 'D')
     mito.merge_sheets('lookup', 0, 'A', ['A', 'B', 'C', 'D'], 1, 'A', ['A', 'B', 'C'])
     mito.add_column(0, 'AAA')
-    mito.delete_column(0, 'AAA')
+    mito.delete_columns(0, ['AAA'])
 
     assert mito.transpiled_code == [
         "df1.insert(3, 'D', 0)", 
@@ -176,7 +176,7 @@ def test_optimization_with_other_edits():
         'temp_df = df2.drop_duplicates(subset=\'A\') # Remove duplicates so lookup merge only returns first match', 
         'df3 = df1.merge(temp_df, left_on=[\'A\'], right_on=[\'A\'], how=\'left\', suffixes=[\'_df1\', \'_df2\'])',
         'df1.insert(4, \'AAA\', 0)',
-        'df1.drop(\'AAA\', axis=1, inplace=True)'
+        'df1.drop([\'AAA\'], axis=1, inplace=True)'
     ]
 
 TAB = '    '
