@@ -318,11 +318,11 @@ class MitoWidgetTestWrapper:
             }
         )
 
-    def delete_column(self, sheet_index: int, column_header: str):
-        column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
+    def delete_columns(self, sheet_index: int, column_headers: List[str]):
+        column_ids = [self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
             sheet_index,
-            column_header
-        )
+            column_header 
+        ) for column_header in column_headers]
 
         return self.mito_widget.receive_message(
             self.mito_widget,
@@ -333,7 +333,7 @@ class MitoWidgetTestWrapper:
                 'step_id': get_new_id(),
                 'params': {
                     'sheet_index': sheet_index,
-                    'column_id': column_id,
+                    'column_ids': column_ids,
                 }
             }
         )
@@ -374,6 +374,23 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    def excel_import(self, file_name: str, sheet_names: List[str], has_headers: bool, skiprows: int):
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'excel_import_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'file_name': file_name,
+                    'sheet_names': sheet_names,
+                    'has_headers': has_headers,
+                    'skiprows': skiprows,
+                }   
+            }
+        )
+
     def bulk_old_rename(self, move_to_deprecated_id_algorithm=False):
         return self.mito_widget.receive_message(
             self.mito_widget,
