@@ -119,6 +119,7 @@ def df_to_json_dumpsable(
         data: {
             columnID: string;
             columnHeader: (string | number);
+            columnDtype: string;
             columnData: (string | number)[];
         }[];
         columnIDsMap: ColumnIDsMap;
@@ -172,6 +173,7 @@ def df_to_json_dumpsable(
         column_final_data = {
             'columnID': column_headers_to_column_ids[column_header],
             'columnHeader': column_header,
+            'columnDtype': str(df[column_header].dtype),
             'columnData': []
         }
         for row in json_obj['data']:
